import os
import sys
import platform
import json
from typing import Tuple

from livekit import rtc


def dylib_path(name: str) -> str:
    base_dir = os.path.dirname(__file__)
    resources_dir = os.path.join(base_dir, "resources")

    arch = platform.machine().lower()

    if sys.platform == "linux":
        ext = ".so"
    elif sys.platform == "darwin":
        ext = ".dylib"
    elif sys.platform == "win32":
        ext = ".dll"
    else:
        raise RuntimeError(f"Unsupported platform: {sys.platform}")

    return os.path.join(resources_dir, f"{name}{ext}")

def resource_path(name: str) -> str:
    base_dir = os.path.dirname(__file__)
    resources_dir = os.path.join(base_dir, "resources")
    return os.path.join(resources_dir, name)

def plugin_path() -> str:
    return dylib_path("liblivekit_nc_plugin")

def dependencies_path() -> list[str]:
    return [dylib_path("libonnxruntime")]

def model_path(model: str) -> str:
    if model == "nc":
        return resource_path("c8.f.s.026300-1.0.0_2.1.kef")
    else:
        raise RuntimeError(f"Unsupported model: {model}")

def NC() -> rtc.NoiseCancellationOptions:
    return rtc.NoiseCancellationOptions(str(id(sys.modules.get("livekit.plugins.noise_cancellation"))), {
        "modelPath": model_path("nc"),
    })

